import * as cdk from '@aws-cdk/core';
/**
 * The supported annotation types.
 *
 * Only error will stop deployment of restricted resources.
 *
 * @stability stable
 */
export declare enum AnnotationType {
    /**
     * @stability stable
     */
    WARNING = "warning",
    /**
     * @stability stable
     */
    ERROR = "error",
    /**
     * @stability stable
     */
    INFO = "info"
}
/**
 * The base aspect properties available to any aspect.
 *
 * JSII doesn't support an Omit when extending interfaces, so we create a base class to extend from.
 * This base class meets the needed properties for all non-base aspects.
 *
 * @stability stable
 */
export interface AspectPropsBase {
    /**
     * The annotation text to use for the annotation.
     *
     * @stability stable
     */
    readonly annotationText?: string;
    /**
     * The annotation type to use for the annotation.
     *
     * @stability stable
     */
    readonly annotationType?: AnnotationType;
}
/**
 * The extended aspect properties available only to the base security aspects.
 *
 * These additional properties shouldn't be changed in aspects that already have clearly defined goals.
 * So, this extended properties interface is applied selectively to the base aspects.
 *
 * @stability stable
 */
export interface AspectPropsExtended extends AspectPropsBase {
    /**
     * The restricted port.
     *
     * Defaults to restricting all ports and only checking sources.
     *
     * @default undefined
     * @stability stable
     */
    readonly ports?: number[];
    /**
     * The restricted CIDRs for the given port.
     *
     * @default ['0.0.0.0/0', '::/0']
     * @stability stable
     */
    readonly restrictedCidrs?: string[];
    /**
     * The restricted source security groups for the given port.
     *
     * @default undefined
     * @stability stable
     */
    readonly restrictedSGs?: string[];
    /**
     * Whether any source is valid.
     *
     * This will ignore all other restrictions and only check the port.
     *
     * @default false
     * @stability stable
     */
    readonly anySource?: boolean;
}
/**
 * @function anyInRange
 * Function to check if a number is in a range.
 *
 * Useful for determining if a port number in a security group is in part of a range since rules take a to and from port.
 *
 * @param num The number to check.
 * @param from The starting number of the range.
 * @param to The ending number of the range.
 */
export declare function anyInRange(num: number[], from: number, to: number): boolean;
/**
 * @function annotate
 * Function to annotate a construct node based on a defined annotation type.
 *
 * @param {cdk.IConstruct} node The construct node to annotate.
 * @param {string} annotationText The annotation text to use for the annotation.
 * @param {AnnotationType} annotationType The annotation type to use for the annotation.
 */
export declare function annotate(node: cdk.IConstruct, annotationText: string | undefined, annotationType: AnnotationType | undefined): void;
/**
 * The arguments for the checkRules function.
 *
 * Extends the IAspectPropsBase interface which includes additional properties that can be used as args.
 *
 * @stability stable
 */
export interface RuleCheckArgs extends AspectPropsExtended {
    /**
     * The node to check.
     *
     * @stability stable
     */
    readonly node: cdk.IConstruct;
}
/**
 * @function checkRules
 *
 * @param {IRuleCheckArgs} args The arguments for the checkRules function.
 *
 * Function to check a node for security group rules and determine if they breaks the rules of a given aspect.
 */
export declare function checkRules(args: RuleCheckArgs): void;
/**
 * The base class for all security group aspects in the library.
 *
 * By default this will not restrict anything.
 *
 * @stability stable
 */
export declare class SecurityGroupAspectBase implements cdk.IAspect {
    /**
     * @stability stable
     */
    annotationText: string;
    /**
     * @stability stable
     */
    annotationType: AnnotationType;
    /**
     * @stability stable
     */
    ports: number[] | undefined;
    /**
     * @stability stable
     */
    restrictedCidrs: string[] | undefined;
    /**
     * @stability stable
     */
    restrictedSGs: string[] | undefined;
    /**
     * @stability stable
     */
    anySource: boolean;
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsExtended);
    /**
     * All aspects can visit an IConstruct.
     *
     * @stability stable
     */
    visit(node: cdk.IConstruct): void;
}
/**
 * The base aspect to determine if a security group allows inbound traffic from the public internet to any port.
 *
 * This inherits everything from the base SecurityGroupAspectBase class and sets a default set of CIDRS that match allowing all IPs on AWS.
 *
 * @stability stable
 */
export declare class NoPublicIngressAspectBase extends SecurityGroupAspectBase implements cdk.IAspect {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * The same as the base NoPublicIngressAspectBase but with a more descriptive annotation.
 *
 * Blocks the ANY port from the public internet.
 *
 * @stability stable
 */
export declare class NoPublicIngressAspect extends NoPublicIngressAspectBase implements cdk.IAspect {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to determine if a security group allows inbound traffic from the public internet to the SSH port.
 *
 * @stability stable
 */
export declare class NoPublicIngressSSHAspect extends NoPublicIngressAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * CIS AWS Foundations Benchmark 4.1.
 *
 * CIS recommends that no security group allow unrestricted ingress access to port 22. Removing unfettered connectivity to remote console services, such as SSH, reduces a server's exposure to risk.
 *
 * This aspect uses the NoPublicIngressSSHAspect with an alternate annotation text.
 *
 * @stability stable
 */
export declare class CISAwsFoundationBenchmark4Dot1Aspect extends NoPublicIngressSSHAspect {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to determine if a security group allows inbound traffic from the public internet to the RDP port.
 *
 * @stability stable
 */
export declare class NoPublicIngressRDPAspect extends NoPublicIngressAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * CIS AWS Foundations Benchmark 4.2.
 *
 * CIS recommends that no security group allow unrestricted ingress access to port 3389. Removing unfettered connectivity to remote console services, such as RDP, reduces a server's exposure to risk.
 *
 * This aspect uses the NoPublicIngressRDPAspect with an alternate annotation text.
 *
 * @stability stable
 */
export declare class CISAwsFoundationBenchmark4Dot2Aspect extends NoPublicIngressRDPAspect {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Restricted common ports based on AWS Config rule https://docs.aws.amazon.com/config/latest/developerguide/restricted-common-ports.html.
 *
 * @stability stable
 */
export declare class AWSRestrictedCommonPortsAspect extends NoPublicIngressAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to restrict public access to common management ports.
 *
 * 22 - SSH
 * 3389 - RDP
 * 5985 - WinRM
 * 5986 - WinRM HTTPS
 *
 * @stability stable
 */
export declare class NoPublicIngressCommonManagementPortsAspect extends NoPublicIngressAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to restrict any access to common management ports.
 *
 * 22 - SSH
 * 3389 - RDP
 * 5985 - WinRM
 * 5986 - WinRM HTTPS
 *
 * @stability stable
 */
export declare class NoIngressCommonManagementPortsAspect extends SecurityGroupAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to restrict public access to common relational DB ports.
 *
 * 3306 - MySQL
 * 5432 - PostgreSQL
 * 1521 - Oracle
 * 1433 - SQL Server
 *
 * @stability stable
 */
export declare class NoPublicIngressCommonRelationalDBPortsAspect extends NoPublicIngressAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to restrict any access to common relational DB ports.
 *
 * 3306 - MySQL
 * 5432 - PostgreSQL
 * 1521 - Oracle
 * 1433 - SQL Server
 *
 * @stability stable
 */
export declare class NoIngressCommonRelationalDBPortsAspect extends SecurityGroupAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to restrict public access to common web ports.
 *
 * 80 - HTTP
 * 443 - HTTPS
 * 8080 - HTTP
 * 8443 - HTTPS
 *
 * @stability stable
 */
export declare class NoPublicIngressCommonWebPortsAspect extends NoPublicIngressAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
/**
 * Aspect to restrict any access to common web ports.
 *
 * 80 - HTTP
 * 443 - HTTPS
 * 8080 - HTTP
 * 8443 - HTTPS
 *
 * @stability stable
 */
export declare class NoIngressCommonWebPortsAspect extends SecurityGroupAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: AspectPropsBase);
}
